<?php

switch ($messaggio) {

case "Tabella tariffe del":  			$messaggio = "Tableau tarifs de"; break;
case "Torna indietro":  			$messaggio = "Retourner"; break;
case "tariffa":  				$messaggio = "tarif"; break;
case "aggiungi":  				$messaggio = "Ajouter"; break;
case "settimane":  				$messaggio = "semaine"; break;
case "giorni":  				$messaggio = "jours"; break;
case "la nuova foto è stata aggiunta":  	$messaggio = "la nouvelle photo a été ajoutée"; break;
case "l'url della foto è sbagliata":  		$messaggio = "l'url de la photo est erroné"; break;
case "foto eliminata":  			$messaggio = "photo supprimée"; break;
case "foto della tariffa":  			$messaggio = "photo du tarif"; break;
case "elimina":  				$messaggio = "supprimer"; break;
case "url di una nuova foto":  			$messaggio = "url d'une nouvelle photo"; break;
case "descrizione della tariffa":  		$messaggio = "description du tarif"; break;
case "modifica":  				$messaggio = "modifier"; break;
case "aggiornata":  				$messaggio = "mise à jour"; break;
case "commento":  				$messaggio = "commentaire"; break;
case "commento della foto":  			$messaggio = "commentaire de la photo"; break;
case "aggiornato":  				$messaggio = "mis à jour"; break;
case "disponibilità":  				$messaggio = "availability"; break;
case "permanenza min.":  			$messaggio = "minimum stay"; break;
case "permanenza mass.":  			$messaggio = "maximum stay"; break;
case "mostra disponibilità":  			$messaggio = "show availability"; break;
case "mostra permanenza minima":  		$messaggio = "show minimum stay"; break;
case "raggruppa le date":  			$messaggio = "group dates"; break;
case "in modo predefinito per la tariffa":  	$messaggio = "by default for rate"; break;
case "Numero di persone predefinito per la tariffa":	$messaggio = "Default number of people for rate"; break;
case "Modifica i valori":  			$messaggio = "Modify values"; break;
case "non definito":  				$messaggio = "undefined"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>